summaryrefslogtreecommitdiffstats
path: root/drivers/staging/otus
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/staging/otus')
-rw-r--r--drivers/staging/otus/80211core/cagg.c6
-rw-r--r--drivers/staging/otus/80211core/cmm.c4
-rw-r--r--drivers/staging/otus/80211core/performance.c6
-rw-r--r--drivers/staging/otus/hal/hpmain.c2
-rw-r--r--drivers/staging/otus/ioctl.c25
-rw-r--r--drivers/staging/otus/usbdrv.c14
-rw-r--r--drivers/staging/otus/usbdrv.h4
-rw-r--r--drivers/staging/otus/wrap_buf.c3
-rw-r--r--drivers/staging/otus/wrap_dbg.c3
-rw-r--r--drivers/staging/otus/wrap_ev.c7
-rw-r--r--drivers/staging/otus/wrap_mem.c3
-rw-r--r--drivers/staging/otus/wrap_mis.c3
-rw-r--r--drivers/staging/otus/wrap_pkt.c4
-rw-r--r--drivers/staging/otus/wrap_sec.c3
-rw-r--r--drivers/staging/otus/wrap_usb.c3
-rw-r--r--drivers/staging/otus/wwrap.c8
-rw-r--r--drivers/staging/otus/zdcompat.h10
17 files changed, 13 insertions, 95 deletions
diff --git a/drivers/staging/otus/80211core/cagg.c b/drivers/staging/otus/80211core/cagg.c
index 4942190747a1..dbd0a5f0fcdf 100644
--- a/drivers/staging/otus/80211core/cagg.c
+++ b/drivers/staging/otus/80211core/cagg.c
@@ -2845,7 +2845,7 @@ u16_t zfAggSendAddbaRequest(zdev_t* dev, u16_t *dst, u16_t ac, u16_t up)
/*
- * TBD : Maximum size of managment frame
+ * TBD : Maximum size of management frame
*/
if ((buf = zfwBufAllocate(dev, 1024)) == NULL)
{
@@ -3286,7 +3286,7 @@ u16_t zfAggSendAddbaResponse(zdev_t* dev, struct aggBaFrameParameter *bf)
/*
- * TBD : Maximum size of managment frame
+ * TBD : Maximum size of management frame
*/
if ((buf = zfwBufAllocate(dev, 1024)) == NULL)
{
@@ -3439,7 +3439,7 @@ u16_t zfAggSendBar(zdev_t* dev, TID_TX tid_tx, struct aggBarControl *aggBarCon
/*
- * TBD : Maximum size of managment frame
+ * TBD : Maximum size of management frame
*/
if ((buf = zfwBufAllocate(dev, 1024)) == NULL)
{
diff --git a/drivers/staging/otus/80211core/performance.c b/drivers/staging/otus/80211core/performance.c
index 51b42d54f653..4c10e1d7afd6 100644
--- a/drivers/staging/otus/80211core/performance.c
+++ b/drivers/staging/otus/80211core/performance.c
@@ -27,9 +27,9 @@
#ifdef ZM_ENABLE_PERFORMANCE_EVALUATION
#define ZM_TP_SIZE 50
-struct zsSummary zm_summary;
-struct zsVariation zm_var;
-struct zsThroughput zm_tp;
+static struct zsSummary zm_summary;
+static struct zsVariation zm_var;
+static struct zsThroughput zm_tp;
void zfiPerformanceInit(zdev_t* dev)
{
diff --git a/drivers/staging/otus/hal/hpmain.c b/drivers/staging/otus/hal/hpmain.c
index 322585be2c88..94f9cbbbdefc 100644
--- a/drivers/staging/otus/hal/hpmain.c
+++ b/drivers/staging/otus/hal/hpmain.c
@@ -76,7 +76,7 @@ u32_t zfHpEchoCommand(zdev_t* dev, u32_t value);
#define zm_hp_priv(x) (((struct zsHpPriv*)wd->hpPrivate)->x)
-struct zsHpPriv zgHpPriv;
+static struct zsHpPriv zgHpPriv;
#define ZM_FIRMWARE_WLAN_ADDR 0x200000
#define ZM_FIRMWARE_SPI_ADDR 0x114000
diff --git a/drivers/staging/otus/ioctl.c b/drivers/staging/otus/ioctl.c
index ce04218253dd..6808e69fb354 100644
--- a/drivers/staging/otus/ioctl.c
+++ b/drivers/staging/otus/ioctl.c
@@ -58,9 +58,7 @@
#define ZD_MAX_KEY_SIZE 32
#define ZD_MAX_GENERIC_SIZE 64
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
extern u16_t zfLnxGetVapId(zdev_t *dev);
@@ -248,7 +246,6 @@ int usbdrv_ioctl_setrts(struct net_device *dev, struct iw_param *rrq)
return 0;
}
-#if WIRELESS_EXT > 14
/*
* Encode a WPA or RSN information element as a custom
* element using the hostap format.
@@ -269,7 +266,6 @@ u32 encode_ie(void *buf, u32 bufsize, const u8 *ie, u32 ielen,
p += sprintf(p, "%02x", ie[i]);
return (i == ielen ? p - (u8 *)buf:0);
}
-#endif /* WIRELESS_EXT > 14 */
/*
* Translate scan data returned from the card to a card independent
@@ -284,9 +280,7 @@ char *usbdrv_translate_scan(struct net_device *dev,
char *current_val; /* For rates */
char *last_ev;
int i;
- #if WIRELESS_EXT > 14
- char buf[64*2 + 30];
- #endif
+ char buf[64*2 + 30];
last_ev = current_ev;
@@ -365,10 +359,8 @@ char *usbdrv_translate_scan(struct net_device *dev,
/* Add quality statistics */
iwe.cmd = IWEVQUAL;
- #if WIRELESS_EXT > 18
iwe.u.qual.updated = IW_QUAL_QUAL_UPDATED | IW_QUAL_LEVEL_UPDATED
| IW_QUAL_NOISE_UPDATED;
- #endif
iwe.u.qual.level = list->signalStrength;
iwe.u.qual.noise = 0;
iwe.u.qual.qual = list->signalQuality;
@@ -441,7 +433,6 @@ char *usbdrv_translate_scan(struct net_device *dev,
/* Check if we added any event */
if ((current_val - current_ev) > IW_EV_LCP_LEN)
current_ev = current_val;
- #if WIRELESS_EXT > 14
#define IEEE80211_ELEMID_RSN 0x30
memset(&iwe, 0, sizeof(iwe));
iwe.cmd = IWEVCUSTOM;
@@ -503,7 +494,6 @@ char *usbdrv_translate_scan(struct net_device *dev,
last_ev = current_ev;
}
}
- #endif
/* The other data in the scan result are not really
* interesting, so for now drop it
*/
@@ -697,12 +687,9 @@ int usbdrvwext_giwrange(struct net_device *dev,
if (!netif_running(dev))
return -EINVAL;
- #if WIRELESS_EXT > 9
range->txpower_capa = IW_TXPOW_DBM;
/* XXX what about min/max_pmp, min/max_pmt, etc. */
- #endif
- #if WIRELESS_EXT > 10
range->we_version_compiled = WIRELESS_EXT;
range->we_version_source = 13;
@@ -710,7 +697,6 @@ int usbdrvwext_giwrange(struct net_device *dev,
range->retry_flags = IW_RETRY_LIMIT;
range->min_retry = 0;
range->max_retry = 255;
- #endif /* WIRELESS_EXT > 10 */
channel_num = zfiWlanQueryAllowChannels(dev, channels);
@@ -917,13 +903,11 @@ int usbdrvwext_giwscan(struct net_device *dev,
current_ev = usbdrv_translate_scan(dev, info, current_ev,
end_buf, &pBssList->bssInfo[i]);
- #if WIRELESS_EXT > 16
if (current_ev == end_buf) {
kfree(pBssList);
data->length = current_ev - extra;
return -E2BIG;
}
- #endif
}
/* Length of data */
@@ -2045,6 +2029,7 @@ int usbdrv_wpa_ioctl(struct net_device *dev, struct athr_wlan_param *zdparm)
struct zsKeyInfo keyInfo;
struct usbdrv_private *macp = dev->ml_priv;
u16_t vapId = 0;
+ int ii;
/* zmw_get_wlan_dev(dev); */
@@ -2168,7 +2153,6 @@ int usbdrv_wpa_ioctl(struct net_device *dev, struct athr_wlan_param *zdparm)
/* DUMP key context */
/* #ifdef WPA_DEBUG */
if (keyInfo.keyLength > 0) {
- int ii;
printk(KERN_WARNING
"Otus: Key Context:\n");
for (ii = 0; ii < keyInfo.keyLength; ) {
@@ -2266,7 +2250,6 @@ int usbdrv_wpa_ioctl(struct net_device *dev, struct athr_wlan_param *zdparm)
/* zfiWlanSetWpaIe(dev, zdparm->u.generic_elem.data,
* zdparm->u.generic_elem.len);
*/
- int ii;
u8_t len = zdparm->u.generic_elem.len;
u8_t *wpaie = (u8_t *)zdparm->u.generic_elem.data;
@@ -2401,7 +2384,7 @@ int usbdrv_ioctl(struct net_device *dev, struct ifreq *ifr, int cmd)
struct athr_wlan_param zdparm;
struct usbdrv_private *macp = dev->ml_priv;
- int err = 0;
+ int err = 0, val = 0;
int changed = 0;
/* regp = macp->regp; */
@@ -2445,7 +2428,7 @@ int usbdrv_ioctl(struct net_device *dev, struct ifreq *ifr, int cmd)
err = -EPERM;
break;
}
- int val = *((int *) wrq->u.name);
+ val = *((int *) wrq->u.name);
if ((val < 0) || (val > 2)) {
err = -EINVAL;
break;
diff --git a/drivers/staging/otus/usbdrv.c b/drivers/staging/otus/usbdrv.c
index 7cd87caa6812..48aa30a62164 100644
--- a/drivers/staging/otus/usbdrv.c
+++ b/drivers/staging/otus/usbdrv.c
@@ -39,9 +39,7 @@
#include "linux/netlink.h"
#include "linux/rtnetlink.h"
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
#ifdef ZM_HOSTAPD_SUPPORT
#include "athr_common.h"
@@ -113,9 +111,6 @@ extern u8_t zfLnxCreateThread(zdev_t *dev);
/* Definition of Wireless Extension */
-#if WIRELESS_EXT > 12
-#include <net/iw_handler.h>
-#endif
//wireless extension helper functions
extern int usbdrv_ioctl_setessid(struct net_device *dev, struct iw_point *erq);
extern int usbdrv_ioctl_setrts(struct net_device *dev, struct iw_param *rrq);
@@ -203,7 +198,6 @@ struct iw_priv_args usbdrv_private_args[] = {
// { SIOCIWFIRSTPRIV + 0xC, 0, IW_PRIV_TYPE_CHAR | 12, "get_mac_mode" },
};
-#if WIRELESS_EXT > 12
static iw_handler usbdrvwext_handler[] = {
(iw_handler) NULL, /* SIOCSIWCOMMIT */
(iw_handler) usbdrvwext_giwname, /* SIOCGIWNAME */
@@ -229,13 +223,8 @@ static iw_handler usbdrvwext_handler[] = {
(iw_handler) usbdrvwext_giwap, /* SIOCGIWAP */
(iw_handler) NULL, /* -- hole -- */
(iw_handler) usbdrvwext_iwaplist, /* SIOCGIWAPLIST */
-#if WIRELESS_EXT > 13
(iw_handler) usbdrvwext_siwscan, /* SIOCSIWSCAN */
(iw_handler) usbdrvwext_giwscan, /* SIOCGIWSCAN */
-#else /* WIRELESS_EXT > 13 */
- (iw_handler) NULL, /* null */ /* SIOCSIWSCAN */
- (iw_handler) NULL, /* null */ /* SIOCGIWSCAN */
-#endif /* WIRELESS_EXT > 13 */
(iw_handler) usbdrvwext_siwessid, /* SIOCSIWESSID */
(iw_handler) usbdrvwext_giwessid, /* SIOCGIWESSID */
@@ -291,7 +280,6 @@ static struct iw_handler_def p80211wext_handler_def = {
.private = (iw_handler *) usbdrv_private_handler,
.private_args = (struct iw_priv_args *) usbdrv_private_args
};
-#endif
/* WDS */
//struct zsWdsStruct wds[ZM_WDS_PORT_NUMBER];
@@ -1106,9 +1094,7 @@ u8_t zfLnxInitSetup(struct net_device *dev, struct usbdrv_private *macp)
dev->dev_addr[4] = addr[4];
dev->dev_addr[5] = addr[5];
#endif
-#if WIRELESS_EXT > 12
dev->wireless_handlers = (struct iw_handler_def *)&p80211wext_handler_def;
-#endif
dev->netdev_ops = &otus_netdev_ops;
diff --git a/drivers/staging/otus/usbdrv.h b/drivers/staging/otus/usbdrv.h
index a11b3b36a906..78004062caba 100644
--- a/drivers/staging/otus/usbdrv.h
+++ b/drivers/staging/otus/usbdrv.h
@@ -61,10 +61,6 @@
#define USB_REG_IN_PIPE 3
#define USB_REG_OUT_PIPE 4
-#if (WLAN_HOSTIF == WLAN_USB)
-#include <linux/usb.h>
-#endif
-
#ifdef ZM_HOSTAPD_SUPPORT
#include "athr_common.h"
#endif
diff --git a/drivers/staging/otus/wrap_buf.c b/drivers/staging/otus/wrap_buf.c
index 62496a0f8e3f..a0f677a52616 100644
--- a/drivers/staging/otus/wrap_buf.c
+++ b/drivers/staging/otus/wrap_buf.c
@@ -30,10 +30,7 @@
#include <linux/netlink.h>
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
-
/* Called to allocate buffer, must return a continue buffer space */
diff --git a/drivers/staging/otus/wrap_dbg.c b/drivers/staging/otus/wrap_dbg.c
index 53763d9d2d85..d47e9ab9179a 100644
--- a/drivers/staging/otus/wrap_dbg.c
+++ b/drivers/staging/otus/wrap_dbg.c
@@ -27,10 +27,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
void zfwDumpBuf(zdev_t* dev, zbuf_t* buf)
{
diff --git a/drivers/staging/otus/wrap_ev.c b/drivers/staging/otus/wrap_ev.c
index 966b787eef62..bcda0b9673dc 100644
--- a/drivers/staging/otus/wrap_ev.c
+++ b/drivers/staging/otus/wrap_ev.c
@@ -28,10 +28,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
/***** Management *****/
@@ -75,7 +72,6 @@ u16_t zfLnxAsocNotify(zdev_t* dev, u16_t* macAddr, u8_t* body, u16_t bodySize, u
// //wireless_send_event(macp->device, SIOCGIWSCAN, &wreq, NULL);
// wireless_send_event(macp->device, SIOCGIWAP, &wreq, NULL);
//}
-#if WIRELESS_EXT >= 15
//else if(macp->cardSetting.BssType == AP_BSS) {
// if (port == 0)
// {
@@ -94,7 +90,6 @@ u16_t zfLnxAsocNotify(zdev_t* dev, u16_t* macAddr, u8_t* body, u16_t bodySize, u
// }
// }
//}
-#endif
//#endif
return 0;
@@ -185,7 +180,6 @@ void zfLnxConnectNotify(zdev_t* dev, u16_t status, u16_t* bssid)
// //wireless_send_event(dev, SIOCGIWSCAN, &wreq, NULL);
wireless_send_event(dev, SIOCGIWAP, &wreq, NULL);
}
-#if WIRELESS_EXT >= 15
else if(zfiWlanQueryWlanMode(dev) == ZM_MODE_AP) {
//if (port == 0)
//{
@@ -204,7 +198,6 @@ void zfLnxConnectNotify(zdev_t* dev, u16_t status, u16_t* bssid)
// }
//}
}
-#endif
}
//return 0;
}
diff --git a/drivers/staging/otus/wrap_mem.c b/drivers/staging/otus/wrap_mem.c
index 8081bb2f8878..32416d77a471 100644
--- a/drivers/staging/otus/wrap_mem.c
+++ b/drivers/staging/otus/wrap_mem.c
@@ -27,10 +27,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
/* Memory management */
/* Called to allocate uncached memory, allocated memory must */
diff --git a/drivers/staging/otus/wrap_mis.c b/drivers/staging/otus/wrap_mis.c
index 337918b9de9a..ea2199fecbbe 100644
--- a/drivers/staging/otus/wrap_mis.c
+++ b/drivers/staging/otus/wrap_mis.c
@@ -28,10 +28,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
//extern struct zsWdsStruct wds[ZM_WDS_PORT_NUMBER];
extern struct zsVapStruct vap[ZM_VAP_PORT_NUMBER];
diff --git a/drivers/staging/otus/wrap_pkt.c b/drivers/staging/otus/wrap_pkt.c
index 89a6b92f5972..0d5920fdf4f3 100644
--- a/drivers/staging/otus/wrap_pkt.c
+++ b/drivers/staging/otus/wrap_pkt.c
@@ -28,11 +28,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
-
//extern struct zsWdsStruct wds[ZM_WDS_PORT_NUMBER];
diff --git a/drivers/staging/otus/wrap_sec.c b/drivers/staging/otus/wrap_sec.c
index f688d064175d..0f780bacc598 100644
--- a/drivers/staging/otus/wrap_sec.c
+++ b/drivers/staging/otus/wrap_sec.c
@@ -28,10 +28,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
#ifdef ZM_ENABLE_CENC
extern int zfLnxCencSendMsg(struct sock *netlink_sk, u_int8_t *msg, int len);
diff --git a/drivers/staging/otus/wrap_usb.c b/drivers/staging/otus/wrap_usb.c
index c076e5645224..70fd410bc894 100644
--- a/drivers/staging/otus/wrap_usb.c
+++ b/drivers/staging/otus/wrap_usb.c
@@ -28,10 +28,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
extern void zfLnxInitUsbTxQ(zdev_t* dev);
extern void zfLnxInitUsbRxQ(zdev_t* dev);
diff --git a/drivers/staging/otus/wwrap.c b/drivers/staging/otus/wwrap.c
index 4db8f6e75ad8..53d2a45d55f9 100644
--- a/drivers/staging/otus/wwrap.c
+++ b/drivers/staging/otus/wwrap.c
@@ -26,10 +26,7 @@
#include "usbdrv.h"
#include <linux/netlink.h>
-
-#if WIRELESS_EXT > 12
#include <net/iw_handler.h>
-#endif
extern void zfiRecv80211(zdev_t* dev, zbuf_t* buf, struct zsAdditionInfo* addInfo);
extern void zfCoreRecv(zdev_t* dev, zbuf_t* buf, struct zsAdditionInfo* addInfo);
@@ -1018,11 +1015,6 @@ void kevent(struct work_struct *work)
container_of(work, struct usbdrv_private, kevent);
zdev_t *dev = macp->device;
- if (macp == NULL)
- {
- return;
- }
-
if (test_and_set_bit(0, (void *)&smp_kevent_Lock))
{
//schedule_work(&macp->kevent);
diff --git a/drivers/staging/otus/zdcompat.h b/drivers/staging/otus/zdcompat.h
index d9a3b2d5ba1e..84ac43356b77 100644
--- a/drivers/staging/otus/zdcompat.h
+++ b/drivers/staging/otus/zdcompat.h
@@ -35,16 +35,6 @@
#undef netdevice_t
typedef struct net_device netdevice_t;
-#ifdef WIRELESS_EXT
-#if (WIRELESS_EXT < 13)
-struct iw_request_info
-{
- __u16 cmd; /* Wireless Extension command */
- __u16 flags; /* More to come ;-) */
-};
-#endif
-#endif
-
#ifndef in_atomic
#define in_atomic() 0
#endif
diff --git a/drivers/staging/otus/80211core/cmm.c b/drivers/staging/otus/80211core/cmm.c
index b74379d928f6..bed16b581a5f 100644
--- a/drivers/staging/otus/80211core/cmm.c
+++ b/drivers/staging/otus/80211core/cmm.c
@@ -871,7 +871,7 @@ void zfSendMmFrame(zdev_t* dev, u8_t frameType, u16_t* dst,
zmw_declare_for_critical_section();
zm_msg2_mm(ZM_LV_2, "Send mm frame, type=", frameType);
/* TBD : Maximum size of managment frame */
if ((buf = zfwBufAllocate(dev, 1024)) == NULL)
{
zm_msg0_mm(ZM_LV_0, "Alloc mm buf Fail!");
@@ -1099,7 +1099,7 @@ void zfSendMmFrame(zdev_t* dev, u8_t frameType, u16_t* dst,
}
if ((wd->sta.capability[1] & ZM_BIT_0) == 1)
- { //spectrum managment flag enable
+ { //spectrum management flag enable
offset = zfStaAddIePowerCap(dev, buf, offset);
offset = zfStaAddIeSupportCh(dev, buf, offset);
}
@@ -871,7 +871,7 @@ void zfSendMmFrame(zdev_t* dev, u8_t frameType, u16_t* dst,
zmw_declare_for_critical_section();
zm_msg2_mm(ZM_LV_2, "Send mm frame, type=", frameType);
- /* TBD : Maximum size of managment frame */
+ /* TBD : Maximum size of management frame */
if ((buf = zfwBufAllocate(dev, 1024)) == NULL)
{